#### Generate some basic ordination plots to take a first look at the data ####
# Generate PCOA plots; unifrac
unifrac_dism <- distance(DISEASE_RARE, method="unifrac")
pcoa_unifrac <- ordinate(DISEASE_RARE, method="PCoA", distance=unifrac_dism)

plot_Age_Sex <- plot_ordination(DISEASE_RARE, pcoa_unifrac, 
                             color = "Age", shape="Sex") +
  theme_bw() + theme(panel.border = element_blank()) +
  scale_color_gradient(low="LightGreen", high="DarkRed") + 
  labs(pch="Sex", col = "Age")
plot_Age_Sex

plot_Bristol_Sex <- plot_ordination(DISEASE_RARE, pcoa_unifrac, 
                                color = "Bristol", shape="Sex") +
  theme_bw() + theme(panel.border = element_blank()) +
  scale_color_gradient(low="LightGreen", high="DarkRed") + 
  labs(pch="Sex", col = "Bristol Score")
plot_Bristol_Sex

# Generate PCOA plots; Bray
bray_dism <- distance(DISEASE_RARE, method="bray")
pcoa_bray <- ordinate(DISEASE_RARE, method="PCoA", distance=bray_dism)

plot_Age_Sex_Bray <- plot_ordination(DISEASE_RARE, pcoa_bray, 
                                color = "Age", shape="Sex") +
  theme_bw() + theme(panel.border = element_blank()) +
  scale_color_gradient(low="LightGreen", high="DarkRed") + 
  labs(pch="Sex", col = "Age")
plot_Age_Sex_Bray

plot_Bristol_Sex_Bray <- plot_ordination(DISEASE_RARE, pcoa_bray, 
                                    color = "Bristol", shape="Sex") +
  theme_bw() + theme(panel.border = element_blank()) +
  scale_color_gradient(low="LightGreen", high="DarkRed") + 
  labs(pch="Sex", col = "Bristol Score")
plot_Bristol_Sex_Bray

plot_Bray <- plot_ordination(DISEASE_RARE, pcoa_unifrac, 
                                         color = "Age_onset", shape="Sex") +
  theme_bw() + theme(panel.border = element_blank()) +
  scale_color_gradient(low="LightGreen", high="DarkRed") + 
  labs(pch="Sex", col = "Age of onset")
plot_Bray

#### Statistical tests? ####
dmunifrac <- UniFrac(DISEASE_RARE, weighted=TRUE)
sample_data <- as.data.frame(sample_data(DISEASE_RARE)) 
adonis2(dmunifrac ~ Disease, permutations = 9999, data= sample_data) 
# Encountering an error here: Error in terms.formula(formula, data = data) : 
# 'data' argument is of the wrong type

# Attempted another diversity metric, also encountered the same error
dm_bray <- vegdist(t(otu_table(DISEASE_ONLY)), method="bray")
adonis2(dm_bray ~ sex, data=dat)

# Checked if coercion into a data frame worked 
is.data.frame(dat) # TRUE0

#### Also compared measures of alpha-diversity ####
alphadiv <- estimate_richness(DISEASE_RARE)
sampdat <- sample_data(DISEASE_RARE)
sampdatwdiv <- data.frame(sampdat, alphadiv)

# Categorical variables
wilcox.test(sampdatwdiv$Shannon ~ sampdatwdiv$Sex) # p-value = 0.4698
wilcox.test(sampdatwdiv$Shannon ~ sampdatwdiv$Lived_on_farm) # p-value = 0.2869
wilcox.test(sampdatwdiv$Shannon ~ sampdatwdiv$Sleep_problems) # p-value = 0.966
wilcox.test(sampdatwdiv$Shannon ~ sampdatwdiv$Antidepressant_use) # p-value = 0.2747

lm_Shannon <- lm(Shannon ~ Abdominal_discomfort, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.295

lm_Shannon <- lm(Shannon ~ IBS, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.391

lm_Shannon <- lm(Shannon ~ Constipation_RomeIII_status, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.199

lm_Shannon <- lm(Shannon ~ Constipation_severity_score, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.518

lm_Shannon <- lm(Shannon ~ Laxative_use, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.662

lm_Shannon <- lm(Shannon ~ BMI, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.575

lm_Shannon <- lm(Shannon ~ Age, data = sampdatwdiv)
summary(lm_Shannon) # 0.00428 **

lm_Shannon <- lm(Shannon ~ Age_onset, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.00376 **

lm_Shannon <- lm(Shannon ~ Disease_dur, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.343

lm_Shannon <- lm(Shannon ~ BDI_depression_score, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.679

lm_Shannon <- lm(Shannon ~ Depressed, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.956

lm_Shannon <- lm(Shannon ~ BDIOver5, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.456

lm_Shannon <- lm(Shannon ~ FSS_fatigue_score, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.434

lm_Shannon <- lm(Shannon ~ STAI_anxiety_score, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.625

lm_Shannon <- lm(Shannon ~ updrstotal, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.102

lm_Shannon <- lm(Shannon ~ education, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.785

lm_Shannon <- lm(Shannon ~ moca_total, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.259

lm_Shannon <- lm(Shannon ~ sniffintotal, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.0771 . 

lm_Shannon <- lm(Shannon ~ Bristol, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.00238 **

lm_Shannon <- lm(Shannon ~ Apathy_score, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.753

lm_Shannon <- lm(Shannon ~ Abx_doses_last_5_years, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.307

lm_Shannon <- lm(Shannon ~ Alpha_carotene, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.534

lm_Shannon <- lm(Shannon ~ Alcohol, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.544

lm_Shannon <- lm(Shannon ~ Beta_carotene, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.985

lm_Shannon <- lm(Shannon ~ Carotene_total, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.984

lm_Shannon <- lm(Shannon ~ Calcium, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.357

lm_Shannon <- lm(Shannon ~ Carbohydrate_total, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.623

lm_Shannon <- lm(Shannon ~ Cholesterol, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.992

lm_Shannon <- lm(Shannon ~ Chloride, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.611

lm_Shannon <- lm(Shannon ~ Copper, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.927

lm_Shannon <- lm(Shannon ~ Iron, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.153

lm_Shannon <- lm(Shannon ~ Non_Starch_Polysaccharides, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.439

lm_Shannon <- lm(Shannon ~ Total_folate, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.102

lm_Shannon <- lm(Shannon ~ Fructose, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.163

lm_Shannon <- lm(Shannon ~ Galactose, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.477

lm_Shannon <- lm(Shannon ~ Glucose, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.233

lm_Shannon <- lm(Shannon ~ Iodine, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.373

lm_Shannon <- lm(Shannon ~ Potassium, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.654

lm_Shannon <- lm(Shannon ~ Energy_kcal, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.938

lm_Shannon <- lm(Shannon ~ Lactose, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.233

lm_Shannon <- lm(Shannon ~ Maltose, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.842

lm_Shannon <- lm(Shannon ~ Manganese, data = sampdatwdiv)
summary(lm_Shannon) # 0.413

lm_Shannon <- lm(Shannon ~ Sodium, data = sampdatwdiv)
summary(lm_Shannon) # 0.529

lm_Shannon <- lm(Shannon ~ Niacin, data = sampdatwdiv)
summary(lm_Shannon) # 0.822

lm_Shannon <- lm(Shannon ~ Phosphorus, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.552

lm_Shannon <- lm(Shannon ~ Protein, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.717

lm_Shannon <- lm(Shannon ~ Vitamin_A, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.470

lm_Shannon <- lm(Shannon ~ Vitamin_B2, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.0137 *

lm_Shannon <- lm(Shannon ~ Vitamin_B1, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.635

lm_Shannon <- lm(Shannon ~ Vitamin_B12, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.299

lm_Shannon <- lm(Shannon ~ Vitamin_B6, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.427

lm_Shannon <- lm(Shannon ~ Vitamin_C, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.298

lm_Shannon <- lm(Shannon ~ Vitamin_D, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.993

lm_Shannon <- lm(Shannon ~ Vitamin_E, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.490

lm_Shannon <- lm(Shannon ~ Selenium, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.734

lm_Shannon <- lm(Shannon ~ Starch, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.894

lm_Shannon <- lm(Shannon ~ Sucrose, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.602

lm_Shannon <- lm(Shannon ~ Nitrogen, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.759

lm_Shannon <- lm(Shannon ~ Sugars_total, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.238

lm_Shannon <- lm(Shannon ~ Zinc, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.605

lm_Shannon <- lm(Shannon ~ Fat_total, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.391

lm_Shannon <- lm(Shannon ~ MUFA, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.175

lm_Shannon <- lm(Shannon ~ PUFA, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.232

lm_Shannon <- lm(Shannon ~ SFA, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.963

lm_Shannon <- lm(Shannon ~ Eggs, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.938

lm_Shannon <- lm(Shannon ~ Alcoholic_beverages, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.545

lm_Shannon <- lm(Shannon ~ Cereals, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.971

lm_Shannon <- lm(Shannon ~ Fats_and_oils, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.967

lm_Shannon <- lm(Shannon ~ Fish, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.432

lm_Shannon <- lm(Shannon ~ Fruit, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.300

lm_Shannon <- lm(Shannon ~ Meat, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.978

lm_Shannon <- lm(Shannon ~ Milk, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.123

lm_Shannon <- lm(Shannon ~ Non_alcoholic_bevs, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.782

lm_Shannon <- lm(Shannon ~ Nuts_and_seeds, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.0142 *

lm_Shannon <- lm(Shannon ~ Potatoes, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.221

lm_Shannon <- lm(Shannon ~ Soups_sauces, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.889

lm_Shannon <- lm(Shannon ~ Preserves_and_snacks, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.302

lm_Shannon <- lm(Shannon ~ Fats_and_oils, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.432

lm_Shannon <- lm(Shannon ~ Vegetables, data = sampdatwdiv)
summary(lm_Shannon) # p-value = 0.916
