#### Isolating L-dopa-treated patients only ####
LEVO_ONLY <- subset_samples(PD_INCRM, entacapone == "No" & amantadine == "No" & rasagiline == "No"
                       & pramipexole == "No")
LEVO_ONLY_DATA <- data.frame(sample_data(LEVO_ONLY))

#### Compute beta-diversity metrics ####
dm_wunifrac_levo <- UniFrac(LEVO_ONLY, weighted=TRUE)
dm_unifrac_levo <- UniFrac(LEVO_ONLY, weighted=FALSE)
dm_bray_levo <- vegdist(t(otu_table(LEVO_ONLY)), method="bray")
dm_jaccard_levo <- vegdist(t(otu_table(LEVO_ONLY)), method="jaccard")

adonis2(dm_wunifrac_levo ~ levo_equiv_dose, data=LEVO_ONLY_DATA) # Pr(>F) value = 0.672
adonis2(dm_unifrac_levo ~ levo_equiv_dose, data=LEVO_ONLY_DATA) # Pr(>F) value = 0.51
adonis2(dm_bray_levo ~ levo_equiv_dose, data=LEVO_ONLY_DATA) # Pr(>F) value = 0.414
adonis2(dm_jaccard_levo ~ levo_equiv_dose, data=LEVO_ONLY_DATA) # Pr(>F) value = 0.334
## Therefore, levo alone does not alter beta-diversity. 

#### Generate ordination plot for PD_L patients only based on LED #### 
library("viridis") 
ld_pcoa_wuni <- ordinate(LEVO_ONLY, method="PCoA", distance=dm_wunifrac_levo)
plot_wuni_ld <- plot_ordination(LEVO_ONLY, ld_pcoa_wuni, 
                                 color = "levo_equiv_dose", shape = "Laxative_use") +
  theme_bw() + theme(panel.background=element_rect(colour="black")) +
  scale_color_viridis(option = "D") + 
  labs(col = "LED", shape ="Laxative use") + 
  scale_shape_manual(values = c(16, 4)) 
plot_wuni_ld + stat_ellipse(level = 0.95)
