#### Start by looking at entacapone only ####
## Subset Phyloseq object...
E_and_L_ONLY <- subset_samples(PD_INCRM, amantadine == "No" & rasagiline == "No" &
                         pramipexole == "No")
E_and_L_ONLY_DATA <- data.frame(sample_data(E_and_L_ONLY))

# Then generate beta diversity metrics
dm_wunifrac_el <- UniFrac(E_and_L_ONLY, weighted=TRUE)
dm_unifrac_el <- UniFrac(E_and_L_ONLY, weighted=FALSE)
dm_bray_el <- vegdist(t(otu_table(E_and_L_ONLY)), method="bray")
dm_jaccard_el <- vegdist(t(otu_table(E_and_L_ONLY)), method="jaccard")

# Only PERMANOVA using weighted UniFrac metrics shows near-significant of entacapone 
adonis2(dm_wunifrac_el ~ entacapone, data=E_and_L_ONLY_DATA) # Pr(>F) value = 0.062; near-significance
adonis2(dm_unifrac_el ~ entacapone, data=E_and_L_ONLY_DATA) # Pr(>F) value = 0.604
adonis2(dm_bray_el ~ entacapone, data=E_and_L_ONLY_DATA) # Pr(>F) value = 0.133
adonis2(dm_jaccard_el ~ entacapone, data=E_and_L_ONLY_DATA) # Pr(>F) value = 0.154

#### What if if we account for laxative use? ####
## Subset Phyloseq objects 
E_and_L_ONLY_LAX <- subset_samples(E_and_L_ONLY, Laxative_use == "Yes")
E_and_L_ONLY_NOLAX <- subset_samples(E_and_L_ONLY, Laxative_use == "No")
E_and_L_ONLY_LAX_DATA <- data.frame(sample_data(E_and_L_ONLY_LAX))
E_and_L_ONLY_NOLAX_DATA <- data.frame(sample_data(E_and_L_ONLY_NOLAX))

## Laxative use: Yes; entacapone has a significant effect
dm_wunifrac_el_lax <- UniFrac(E_and_L_ONLY_LAX, weighted=TRUE)
adonis2(dm_wunifrac_el_lax ~ entacapone, data=E_and_L_ONLY_LAX_DATA) # Pr(>F) value = 0.007 **

## Laxative use: No; entacapone does NOT have a significant effect
dm_wunifrac_el_nolax <- UniFrac(E_and_L_ONLY_NOLAX, weighted=TRUE)
adonis2(dm_wunifrac_el_nolax ~ entacapone, data=E_and_L_ONLY_NOLAX_DATA) # Pr(>F) value = 0.185

#### Generate ordination plots ####
library(ggplot2) 
library(ggside)
# Make sure to include ellipses that depict the 95% confidence interval 

# Weighted UniFrac, all PD_L and PD_LE subjects
el_pcoa_wuni <- ordinate(E_and_L_ONLY, method="PCoA", distance=dm_wunifrac_el)
plot_wuni <- plot_ordination(E_and_L_ONLY, el_pcoa_wuni, 
                        color = "entacapone") +
  labs(col = "Took entacapone?") + theme_bw() +
  scale_colour_manual(values = c("#ab5348", "#4f9e9d")) +
  ggside::geom_xsideboxplot(aes(fill = entacapone, y = entacapone), orientation = "y") +
  ggside::geom_ysideboxplot(aes(fill = entacapone, x = entacapone), orientation = "x") +
  ggside::scale_xsidey_discrete(labels = NULL) +
  ggside::scale_ysidex_discrete(labels = NULL) +
  ggside::theme_ggside_void()
plot_wuni
plot_wuni + stat_ellipse(level = 0.95)

# Unweighted UniFrac, all PD_L and PD_LE subjects
el_pcoa_uni <- ordinate(E_and_L_ONLY, method="PCoA", distance=dm_unifrac_el)
plot_uni <- plot_ordination(E_and_L_ONLY, el_pcoa_uni, 
                             color = "entacapone") +
  labs(col = "Took entacapone?") + theme_bw() +
  scale_colour_manual(values = c("#ab5348", "#4f9e9d")) +
  ggside::geom_xsideboxplot(aes(fill = entacapone, y = entacapone), orientation = "y") +
  ggside::geom_ysideboxplot(aes(fill = entacapone, x = entacapone), orientation = "x") +
  ggside::scale_xsidey_discrete(labels = NULL) +
  ggside::scale_ysidex_discrete(labels = NULL) +
  ggside::theme_ggside_void()
plot_uni
plot_uni + stat_ellipse(level = 0.95)

# Bray-Curtis Dissimilarity, all PD_L and PD_LE subjects
el_pcoa_bray <- ordinate(E_and_L_ONLY, method="PCoA", distance=dm_bray_el)
plot_bray <- plot_ordination(E_and_L_ONLY, el_pcoa_bray, 
                            color = "entacapone") +
  labs(col = "Took entacapone?") + theme_bw() +
  scale_colour_manual(values = c("#ab5348", "#4f9e9d")) +
  ggside::geom_xsideboxplot(aes(fill = entacapone, y = entacapone), orientation = "y") +
  ggside::geom_ysideboxplot(aes(fill = entacapone, x = entacapone), orientation = "x") +
  ggside::scale_xsidey_discrete(labels = NULL) +
  ggside::scale_ysidex_discrete(labels = NULL) +
  ggside::theme_ggside_void()
plot_bray + stat_ellipse(level = 0.95)

# Jaccard index, all PD_L and PD_LE subjects
el_pcoa_jaccard <- ordinate(E_and_L_ONLY, method="PCoA", distance=dm_jaccard_el)
plot_jaccard <- plot_ordination(E_and_L_ONLY, el_pcoa_jaccard, 
                             color = "entacapone") +
  labs(col = "Took entacapone?") + theme_bw() +
  scale_colour_manual(values = c("#ab5348", "#4f9e9d")) +
  ggside::geom_xsideboxplot(aes(fill = entacapone, y = entacapone), orientation = "y") +
  ggside::geom_ysideboxplot(aes(fill = entacapone, x = entacapone), orientation = "x") +
  ggside::scale_xsidey_discrete(labels = NULL) +
  ggside::scale_ysidex_discrete(labels = NULL) +
  ggside::theme_ggside_void()
plot_jaccard + stat_ellipse(level = 0.95)

# Now generate ordination plots by subsetting based on laxative use
# Only laxative users included
el_lax_pcoa_wuni <- ordinate(E_and_L_ONLY_LAX, method="PCoA", distance=dm_wunifrac_el_lax)
plot_wuni_lax <- plot_ordination(E_and_L_ONLY_LAX, el_lax_pcoa_wuni, 
                             color = "entacapone") + theme_bw() +
  scale_colour_manual(values = c("#ab5348", "#4f9e9d")) +
  ggside::geom_xsideboxplot(aes(fill = entacapone, y = entacapone), orientation = "y") +
  ggside::geom_ysideboxplot(aes(fill = entacapone, x = entacapone), orientation = "x") +
  ggside::scale_xsidey_discrete(labels = NULL) +
  ggside::scale_ysidex_discrete(labels = NULL) +
  ggside::theme_ggside_void() +
  labs(col = "Took entacapone?")
plot_wuni_lax + stat_ellipse(level = 0.95)

# Only non-laxative users included
el_nolax_pcoa_wuni <- ordinate(E_and_L_ONLY_NOLAX, method="PCoA", distance=dm_wunifrac_el_nolax)
plot_wuni_nolax <- plot_ordination(E_and_L_ONLY_NOLAX, el_nolax_pcoa_wuni, 
                                   color = "entacapone") + theme_bw() +
  scale_colour_manual(values = c("#ab5348", "#4f9e9d")) +
  ggside::geom_xsideboxplot(aes(fill = entacapone, y = entacapone), orientation = "y") +
  ggside::geom_ysideboxplot(aes(fill = entacapone, x = entacapone), orientation = "x") +
  ggside::scale_xsidey_discrete(labels = NULL) +
  ggside::scale_ysidex_discrete(labels = NULL) +
  ggside::theme_ggside_void() +
  labs(col = "Took entacapone?")
plot_wuni_nolax + stat_ellipse(level = 0.95)
