#### What is the full range of LED values among PD patients? ####
summary(LEVO_ONLY_DATA$levo_equiv_dose)
## Min. 1st Qu.  Median    Mean   3rd Qu.    Max. 
## 0.0   300.0   460.0    540.4   725.0    1475.0 

# Generate a boxplot to show this visually 
levoplot <- ggplot(LEVO_ONLY_DATA, aes(x=levo_equiv_dose)) +
  geom_boxplot(color="#3c91ab") +   
  scale_y_continuous(breaks = seq(by = 1)) +
  xlab("LED")+
  theme_bw() 
levoplot
+ coord_flip()

#### Compare beta diversity metrics while accounting for LED: First quartile ####
# First, generate a phyloseq object that includes PD_LE patients only
E_ONLY <- subset_samples(E_and_L_ONLY_LAX, entacapone == "Yes")

# Next, subset PD_L subjects based on their LED. We will start by including only the patients in the first quartile.
NO_DRUGS_Q1 <- subset_samples(LEVO_ONLY, levo_equiv_dose <= 300.00 & Laxative_use=="Yes")

# Combine both phyloseq objects. 
E_NODRUG_Q1 <- merge_phyloseq(E_ONLY, NO_DRUGS_Q1)
E_NODRUG_Q1_DATA <- data.frame(sample_data(E_NODRUG_Q1))

# Low LED PD_L patients and PD_LE patients are significantly different. 
dm_wunifrac_eq1 <- UniFrac(E_NODRUG_Q1, weighted=TRUE)
adonis2(dm_wunifrac_eq1 ~ entacapone, data=E_NODRUG_Q1_DATA) #  Pr(>F) value = 0.003 ***

# Generate an ordination plot. 
eq1_pcoa_wuni <- ordinate(E_NODRUG_Q1, method="PCoA", distance=dm_wunifrac_eq1)
plot_wuni_eq1 <- plot_ordination(E_NODRUG_Q1, eq1_pcoa_wuni, 
                                   color = "entacapone") + theme_bw() +
  scale_colour_manual(values = c("#ab5348", "#4f9e9d")) +
  ggside::geom_xsideboxplot(aes(fill = entacapone, y = entacapone), orientation = "y") +
  ggside::geom_ysideboxplot(aes(fill = entacapone, x = entacapone), orientation = "x") +
  ggside::scale_xsidey_discrete(labels = NULL) +
  ggside::scale_ysidex_discrete(labels = NULL) +
  ggside::theme_ggside_void() 
plot_wuni_eq1 + stat_ellipse(level = 0.95)

#### Compare beta diversity metrics while accounting for LED: Second quartile ####
# Subset PD_L subjects based on their LED. We are including only the patients in the second quartile.
NO_DRUGS_Q2 <- subset_samples(LEVO_ONLY, levo_equiv_dose > 300.00 & levo_equiv_dose <= 460.00
                               & Laxative_use=="Yes")

# Combine with phyloseq object that includes only laxative-using PD_LE patients.  
E_NODRUG_Q2 <- merge_phyloseq(E_ONLY, NO_DRUGS_Q2)
E_NODRUG_Q2_DATA <- data.frame(sample_data(E_NODRUG_Q2))

# Low-to-moderate LED PD_L patients and PD_LE patients are significantly different. 
dm_wunifrac_eq2 <- UniFrac(E_NODRUG_Q2, weighted=TRUE)
adonis2(dm_wunifrac_eq2 ~ entacapone, data=E_NODRUG_Q2_DATA) # Pr(>F) value = 0.047 *

# Generate an ordination plot. 
eq2_pcoa_wuni <- ordinate(E_NODRUG_Q2, method="PCoA", distance=dm_wunifrac_eq2)
plot_wuni_eq2 <- plot_ordination(E_NODRUG_Q2, eq2_pcoa_wuni, 
                                  color = "entacapone") + theme_bw() +
  scale_colour_manual(values = c("#ab5348", "#4f9e9d")) +
  ggside::geom_xsideboxplot(aes(fill = entacapone, y = entacapone), orientation = "y") +
  ggside::geom_ysideboxplot(aes(fill = entacapone, x = entacapone), orientation = "x") +
  ggside::scale_xsidey_discrete(labels = NULL) +
  ggside::scale_ysidex_discrete(labels = NULL) +
  ggside::theme_ggside_void() 
plot_wuni_eq2 + stat_ellipse(level = 0.95)

#### Compare beta diversity metrics while accounting for LED: Third quartile ####
# Subset PD_L subjects based on their LED. We are including only the patients in the third quartile.
NO_DRUGS_Q3 <- subset_samples(LEVO_ONLY, levo_equiv_dose > 460.00 & levo_equiv_dose <= 725.00
                              & Laxative_use=="Yes")

# Combine with phyloseq object that includes only laxative-using PD_LE patients.  
E_NODRUG_Q3 <- merge_phyloseq(E_ONLY, NO_DRUGS_Q3)
E_NODRUG_Q3_DATA <- data.frame(sample_data(E_NODRUG_Q3))

# Moderate-to-high LED PD_L patients and PD_LE patients are significantly different. 
dm_wunifrac_eq3 <- UniFrac(E_NODRUG_Q3, weighted=TRUE)
adonis2(dm_wunifrac_eq3 ~ entacapone, data=E_NODRUG_Q3_DATA) # Pr(>F) value = 0.038 *

# Generate an ordination plot. 
eq3_pcoa_wuni <- ordinate(E_NODRUG_Q3, method="PCoA", distance=dm_wunifrac_eq3)
plot_wuni_eq3 <- plot_ordination(E_NODRUG_Q3, eq3_pcoa_wuni, 
                                 color = "entacapone") + theme_bw() +
  scale_colour_manual(values = c("#ab5348", "#4f9e9d")) +
  ggside::geom_xsideboxplot(aes(fill = entacapone, y = entacapone), orientation = "y") +
  ggside::geom_ysideboxplot(aes(fill = entacapone, x = entacapone), orientation = "x") +
  ggside::scale_xsidey_discrete(labels = NULL) +
  ggside::scale_ysidex_discrete(labels = NULL) +
  ggside::theme_ggside_void() 
plot_wuni_eq3 + stat_ellipse(level = 0.95)

#### Compare beta diversity metrics while accounting for LED: Fourth quartile ####
# Subset PD_L subjects based on their LED. We are including only the patients in the fourth quartile.
NO_DRUGS_Q4 <- subset_samples(LEVO_ONLY, levo_equiv_dose > 725.00 & Laxative_use=="Yes")

# Combine with phyloseq object that includes only laxative-using PD_LE patients.  
E_NODRUG_Q4 <- merge_phyloseq(E_ONLY, NO_DRUGS_Q4)
E_NODRUG_Q4_DATA <- data.frame(sample_data(E_NODRUG_Q4))

# High LED PD_L patients and PD_LE patients are significantly different. 
dm_wunifrac_eq4 <- UniFrac(E_NODRUG_Q4, weighted=TRUE)
adonis2(dm_wunifrac_eq4 ~ entacapone, data=E_NODRUG_Q4_DATA) # Pr(>F) value = 0.002 **

# Generate an ordination plot. 
eq4_pcoa_wuni <- ordinate(E_NODRUG_Q4, method="PCoA", distance=dm_wunifrac_eq4)
plot_wuni_eq4 <- plot_ordination(E_NODRUG_Q4, eq4_pcoa_wuni, 
                                 color = "entacapone") + theme_bw() +
  scale_colour_manual(values = c("#ab5348", "#4f9e9d")) +
  ggside::geom_xsideboxplot(aes(fill = entacapone, y = entacapone), orientation = "y") +
  ggside::geom_ysideboxplot(aes(fill = entacapone, x = entacapone), orientation = "x") +
  ggside::scale_xsidey_discrete(labels = NULL) +
  ggside::scale_ysidex_discrete(labels = NULL) +
  ggside::theme_ggside_void() 
plot_wuni_eq4 + stat_ellipse(level = 0.95)

#### Comparing entacapone users only based on laxative use ####
# Here, we are only considering PD_LE patients. 
E_ONLY <- subset_samples(E_and_L_ONLY, entacapone == "Yes" & Age!=64)
E_ONLY_DATA <- data.frame(sample_data(E_ONLY))

# PD_LE patients that take or do not take laxatives are significantly different. 
dm_wunifrac_eonly <- UniFrac(E_ONLY, weighted=TRUE)
adonis2(dm_wunifrac_eonly ~ Laxative_use, data=E_ONLY_DATA) # Pr(>F) value = 0.045 * 
eonly_pcoa_wuni <- ordinate(E_ONLY, method="PCoA", distance=dm_wunifrac_eonly)

# Generate ordination plot
plot_wuni_eonly <- plot_ordination(E_ONLY, eonly_pcoa_wuni, 
                                   color = "Laxative_use") + theme_bw() +
  scale_colour_manual(values = c("#ab5348", "#4f9e9d")) +
  labs(col = "Laxative use")+
  ggside::geom_xsideboxplot(aes(fill = Laxative_use, y = Laxative_use), orientation = "y") +
  ggside::geom_ysideboxplot(aes(fill = Laxative_use, x = Laxative_use), orientation = "x") +
  ggside::scale_xsidey_discrete(labels = NULL) +
  ggside::scale_ysidex_discrete(labels = NULL) +
  ggside::theme_ggside_void() 
plot_wuni_eonly + stat_ellipse(level = 0.95)


