#### Restrict samples to PD_L and PD_LE Samples ####
DISEASE_EL <- subset_samples(PD_INCRM, rasagiline=="No" & 
                               pramipexole=="No" & amantadine=="No")

E_ONLY <- subset_samples(PD_INCRM, entacapone == "Yes")
NO_DRUGS <- subset_samples(PD_INCRM, pramipexole == "No" & entacapone == "No" &
                           rasagiline == "No" & amantadine == "No")
E_NODRUG <- merge_phyloseq(E_ONLY, NO_DRUGS)

# Entacapone does not affect Shannon diversity,
wilcox.test(sampdatwdiv$Shannon ~ sampdatwdiv$entacapone) # p-value = 0.2355 
wilcox.test(sampdatwdiv$Chao1 ~ sampdatwdiv$entacapone) # p-value = 0.1144

# Display both Shannon and Chao1 metrics
plot_richness(E_NODRUG, measures = c("Shannon","Chao1")) +
  geom_boxplot(aes(fill = entacapone),
               position = position_dodge(0.9),coef = 6) +
  geom_dotplot( aes(fill = entacapone),
                binaxis='y', stackdir='center', dotsize = 0.4,
                position = position_dodge(0.9)) + 
  theme_bw()

# Shannon diversity metrics only
plot_richness(E_NODRUG, measures = c("Shannon")) +
  geom_boxplot(aes(fill = entacapone),
               position = position_dodge(0.9), alpha = 0.5) +
  geom_signif( y_position = c(5), xmin = c(0.75), xmax = c(1.25),
               annotation = c("*"), tip_length = 0.01) +
  geom_dotplot( aes(fill = entacapone),
                binaxis='y', stackdir='center', dotsize = 0.4,
                position = position_dodge(0.9)) + 
  theme_bw()
