#### Indicator Species Analysis ####
library(indicspecies)

# First, we will look at PD patients taking laxatives only. 
ELAX_ONLY <- subset_samples(E_and_L_ONLY_LAX, entacapone == "Yes")
LAX_ONLY <- subset_samples(LEVO_ONLY, Laxative_use=="Yes")
LAX_EL <- merge_phyloseq(ELAX_ONLY, LAX_ONLY)

# Glom by genus. 
LAX_EL_GLOM <- tax_glom(LAX_EL, "Genus", NArm = FALSE)
LAX_EL_RA <- transform_sample_counts(LAX_EL_GLOM, fun=function(x) x/sum(x))

# Perform indicator species analysis. Determine indicator taxa among patients taking entacapone and those that do not. 
isa_LAXEL <- multipatt(t(otu_table(LAX_EL_RA)), 
                        cluster = sample_data(LAX_EL_RA)$entacapone)
summary(isa_LAXEL)
taxtable <- tax_table(LAX_EL) %>% as.data.frame() %>% rownames_to_column(var="ASV")

# View results
results_isa_LAXEL <- isa_LAXEL$sign %>%
  rownames_to_column(var="ASV") %>%
  left_join(taxtable) %>%
  filter(p.value<0.05) %>% View() 

# Next, we will look at PD patients that do not take laxatives. 
ENOLAX_ONLY <- subset_samples(E_and_L_ONLY_NOLAX, entacapone == "Yes")
NOLAX_ONLY <- subset_samples(LEVO_ONLY, Laxative_use=="No")
NOLAX_EL <- merge_phyloseq(ENOLAX_ONLY, NOLAX_ONLY)

# Glom by genus
NOLAX_EL_GLOM <- tax_glom(NOLAX_EL, "Genus", NArm = FALSE)
NOLAX_EL_RA <- transform_sample_counts(NOLAX_EL_GLOM, fun=function(x) x/sum(x))

# Perform indicator species analysis. Determine indicator taxa among patients taking entacapone and those that do not. 
isa_NOLAXEL <- multipatt(t(otu_table(NOLAX_EL_RA)), 
                       cluster = sample_data(NOLAX_EL_RA)$entacapone)
summary(isa_NOLAXEL)
taxtable <- tax_table(NOLAX_EL) %>% as.data.frame() %>% rownames_to_column(var="ASV")

# View results 
results_isa_NOLAXEL <- isa_NOLAXEL$sign %>%
  rownames_to_column(var="ASV") %>%
  left_join(taxtable) %>%
  filter(p.value<0.05) %>% View() 


