#### Core microbiome analysis ####
library(tidyverse)
library(phyloseq)
library(microbiome)
library(ggVennDiagram)

## Subset Phyloseq and modify objects
LEVO_LAX <- subset_samples(LEVO_ONLY, Laxative_use=="Yes") # PD_L only, Lax
LEVO_NOLAX <- subset_samples(LEVO_ONLY, Laxative_use=="No") # PD_L only, no lax
ELAX_ONLY <- subset_samples(E_and_L_ONLY_LAX, entacapone == "Yes") # PD_LE only, lax
ENOLAX_ONLY <- subset_samples(E_and_L_ONLY_NOLAX, entacapone == "Yes") # PD_LE only, nolax

# Convert to relative abundance
LEVOLAX_RA <- transform_sample_counts(LEVO_LAX, fun=function(x) x/sum(x))
LEVONOLAX_RA <- transform_sample_counts(LEVO_NOLAX, fun=function(x) x/sum(x))
ELAX_RA <- transform_sample_counts(ELAX_ONLY, fun=function(x) x/sum(x))
ENOLAX_RA <- transform_sample_counts(ENOLAX_ONLY, fun=function(x) x/sum(x))

# Set a prevalence threshold and abundance threshold:
# What ASVs are found in more than 80% of samples in each category?
LEVOLAX_ASVs <- core_members(LEVOLAX_RA, detection=0.001, prevalence = 0.25)
LEVONOLAX_ASVs <- core_members(LEVONOLAX_RA, detection=0.001, prevalence = 0.25)
ELAX_ASVs <- core_members(ELAX_RA, detection=0.001, prevalence = 0.25)
ENOLAX_ASVs <- core_members(ENOLAX_RA, detection=0.001, prevalence = 0.25)

list(LevoLax = LEVOLAX_ASVs, LevoNoLax = LEVONOLAX_ASVs, ELax = ELAX_ASVs, ENoLax = ENOLAX_ASVs)

# Make a Venn-diagram
ggVennDiagram(x=list(LevoLax = LEVOLAX_ASVs, LevoNoLax = LEVONOLAX_ASVs, 
                     ELax = ELAX_ASVs, ENoLax = ENOLAX_ASVs),
              category.names = c("L, laxatives use",
                                 "L, no laxatives",
                                 "LE, laxative use",
                                 "LE, no laxatives"),
              color = "black") + 
  scale_fill_gradient(low = "#F4FAFE", high = "#073025")

